@@ -9,20 +9,16 @@
 from typing import List
 from aiohttp import ClientSession
 from os import path, listdir, makedirs
-from .request import fetch_user_info
-from .assets import StaticPath
 from nonebot import get_driver
 from .config import Config
 from nonebot.log import logger
-import ujson as json
 
-try:
-    plugin_config = Config.parse_obj(get_driver().config)
-    src_api_url = plugin_config.src_api_url
-except Exception as e:
-    logger.error(e)
-    logger.info("未监测到自定义src_api_url, 使用默认值")
-    src_api_url = Config.src_api_url
+plugin_config = Config.parse_obj(get_driver().config)
+src_api_url = plugin_config.src_api_url
+if src_api_url:
+    logger.info("使用自定义src_api_url")
+else:
+    src_api_url = "http://107.182.17.60:17777/api/"
 
 assets_path = path.abspath(path.join(path.dirname(__file__), "assets"))
 
@@ -54,9 +50,3 @@ async def check_char_update() -> List[str]:
                             file.write(await res.read())
                             result.append(k)
             return result
-
-
-async def check_constants_update():
-    res = await fetch_user_info("constants")
-    with open(StaticPath.constants_json, "w", encoding="UTF-8") as f:
-        f.write(json.dumps(res, indent=4))
\ No newline at end of file
