@@ -1,95 +1,21 @@
-"""
- - Author: DiheChen
- - Date: 2021-08-15 22:01:10
- - LastEditTime: 2022-03-27 01:47:04
- - LastEditors: SEAFHMC
- - Description: None
- - GitHub: https://github.com/Chendihe4975
-"""
-from os import path
-from datetime import datetime
-from time import localtime, mktime, strftime
-
-from PIL import Image, ImageDraw, ImageFont
+from PIL import Image
 from nonebot.adapters.onebot.v11 import MessageSegment
+from nonebot.log import logger
+from .assets import StaticPath
+from .adapters.utils import (
+    open_img, choice_ptt_background, DataText, adapter_selector,
+    draw_text, player_time_format, song_time_format, get_song_info
+)
 
-from .assets import StaticPath, ASSETS
-from .request import fetch_user_info
-import ujson as json
-
-
-def player_time_format(time_stamp: int) -> str:
-    struct_time = localtime(time_stamp / 1000)
-    return strftime("%Y-%m-%d %H:%M:%S", struct_time)
-
-
-def song_time_format(date):
-    now = mktime(datetime.now().timetuple())
-    return (now - date / 1000) / 86400
-
-
-def choice_ptt_background(ptt: int):
-    if ptt == -1:
-        return "rating_off.png"
-    ptt /= 100
-    if ptt < 3:
-        return "rating_0.png"
-    elif 3 <= ptt < 7:
-        return "rating_1.png"
-    elif 7 <= ptt < 10:
-        return "rating_2.png"
-    elif 10 <= ptt < 11:
-        return "rating_3.png"
-    elif 11 <= ptt < 12:
-        return "rating_4.png"
-    elif 12 <= ptt < 12.5:
-        return "rating_5.png"
-    else:
-        return "rating_6.png"
-
-
-def track_complete(score: int, lost_count: int) -> str:
-    if not lost_count:
-        return path.join(ASSETS, "recent", "clear_pure.png") if score > int(1e7) else path.join(ASSETS, "recent", "clear_full.png")
-    return path.join(ASSETS, "recent", "clear_normal.png")
-
-
-class DataText:
-    def __init__(self, L, T, size, text, path, anchor="lt") -> None:
-        self.L = L
-        self.T = T
-        self.text = str(text)
-        self.path = path
-        self.font = ImageFont.truetype(self.path, size)
-        self.anchor = anchor
-
-
-def write_text(image: Image.Image, font, text="text", pos=(0, 0), color=(255, 255, 255, 255),
-               anchor="lt", stroke_width=0, stroke_fill="Black") -> Image.Image:
-    rgba_image = image
-    text_overlay = Image.new("RGBA", rgba_image.size, (255, 255, 255, 0))
-    image_draw = ImageDraw.Draw(text_overlay)
-    image_draw.text(pos, text, font=font, fill=color, anchor=anchor, stroke_width=stroke_width, stroke_fill=stroke_fill)
-    return Image.alpha_composite(rgba_image, text_overlay)
-
-
-def draw_text(image, class_text: DataText, R=255, G=255, B=255, A=255, stroke_width=0, stroke_fill="Black") -> Image.Image:
-    font = class_text.font
-    text = class_text.text
-    anchor = class_text.anchor
-    color = (R, G, B, A)
-    return write_text(image, font, text, (class_text.L, class_text.T), color, anchor, stroke_width=stroke_width, stroke_fill=stroke_fill)
-
-
-def open_img(image_path: str) -> Image.Image:
-    with open(image_path, "rb") as f:
-        image = Image.open(f).convert("RGBA")
-    return image
-
-
-def get_song_info() -> list:
-    with open(StaticPath.constants_json, "r", encoding="UTF-8") as f:
-        return json.loads(f.read())
+api_in_use = adapter_selector().upper()
+if api_in_use == "AUA":
+    logger.info("将使用ArcaeaUnlimitedApi")
+    from .adapters.aua.resolver import ApiResult
+elif api_in_use == "ESTERTION":
+    logger.info("将使用EstertionApi")
+    from .adapters.estertion.resolver import ApiResult
+else:
+    logger.error("不支持的Api选项")
 
 
 class UserArcaeaInfo:
@@ -103,25 +29,18 @@ class UserArcaeaInfo:
     async def draw_best30_image(arcaea_id: str):
         UserArcaeaInfo.querying.append(arcaea_id)
         try:
-            data = await fetch_user_info(arcaea_id, recent_only=False)
+            data = ApiResult()
+            await data.get_b30(arcaea_id=arcaea_id)
         except Exception as e:
             UserArcaeaInfo.querying.remove(arcaea_id)
             return str(e)
         UserArcaeaInfo.querying.remove(arcaea_id)
-        name: str = data[2]["data"]["name"]
-        character: int = data[2]["data"]["character"]
-        is_char_uncapped: bool = data[2]["data"]["is_char_uncapped"]
-        is_char_uncapped_override: bool = data[2]["data"]["is_char_uncapped_override"]
-        rating: str = data[2]["data"]["rating"]
-        score_info_list: list = data[3:]
-        score_info_list.sort(
-            key=lambda v: v["data"][0]["rating"], reverse=True)
-        best_total: float = .0
-        for i in (range(30) if len(score_info_list) >= 30 else range(len(score_info_list))):
-            best_total += score_info_list[i]["data"][0]["rating"]
-        best: float = best_total / 30
-        recent: float = (rating / 100 - best * 0.75) / 0.25
-        icon: str = f"{character}u_icon.png" if is_char_uncapped ^ is_char_uncapped_override else f"{character}_icon.png"
+        name: str = data.name
+        rating: str = data.rating
+        best: float = data.best
+        recent: float = data.recent
+        icon: str = data.icon
+        score_info_list = data.score_info_list
         image = Image.new("RGBA", (1800, 3000))
         background = open_img(StaticPath.b30_background)
         image.alpha_composite(background)
@@ -131,9 +50,11 @@ class UserArcaeaInfo:
         ptt_background = open_img(
             StaticPath.select_image("ptt", choice_ptt_background(rating))).resize((150, 150))
         image.alpha_composite(ptt_background, (300, 400))
-        write_ptt = DataText(375, 475, 45, rating / 100 if rating != -
-                             1 else "--", StaticPath.exo_regular, anchor="mm")
-        image = draw_text(image, write_ptt, stroke_fill="Black", stroke_width=2)
+        raw_ptt = str(round(rating/100, 2)).split(".")
+        write_ptt_head = DataText(373, 490, 45, raw_ptt[0], StaticPath.exo_semibold, anchor="rs")
+        image = draw_text(image, write_ptt_head, stroke_fill="Black", stroke_width=2)
+        write_ptt_tail = DataText(373, 490, 35, "."+raw_ptt[1], StaticPath.exo_semibold, anchor="ls")
+        image = draw_text(image, write_ptt_tail, stroke_fill="Black", stroke_width=2)
         write_arcname = DataText(455, 400, 85, name,
                                  StaticPath.geosans_light, anchor="lb")
         image = draw_text(image, write_arcname)
@@ -148,7 +69,7 @@ class UserArcaeaInfo:
         image = draw_text(image, w_b30)
         background_y = 580
         background_x = 0
-        for num, i in enumerate(score_info_list):
+        for num, data in enumerate(score_info_list):
             if num == 30:
                 break
             if num % 3 == 0:
@@ -156,7 +77,8 @@ class UserArcaeaInfo:
                 background_x = 30
             else:
                 background_x += 600
-            data = i["data"][0]
+            if api_in_use == "ESTERTION":
+                data = data["data"][0]
             best30_background = open_img(
                 StaticPath.b30_score_background)
             image.alpha_composite(
@@ -174,7 +96,7 @@ class UserArcaeaInfo:
             image.alpha_composite(
                 rank_background, (395 + background_x, 95 + background_y))
             write_constant = DataText(223 + background_x, 12 + background_y, 20,
-                                      f'{data["constant"]:.1f}', StaticPath.exo_regular, anchor='rt')
+                                      f'{get_song_info()[2]["data"][data["song_id"]][data["difficulty"]]:.1f}', StaticPath.exo_regular, anchor='rt')
             image = draw_text(image, write_constant)
             write_ranking = DataText(480 + background_x, background_y, 45,
                                      f'#{num + 1}', StaticPath.exo_regular, anchor='lm')
@@ -223,39 +145,37 @@ class UserArcaeaInfo:
     async def draw_recent_image(arcaea_id: str):
         UserArcaeaInfo.querying.append(arcaea_id)
         try:
-            data = (await fetch_user_info(arcaea_id, recent_only=True))[0]["data"]
+            data = ApiResult()
+            await data.get_recent(arcaea_id=arcaea_id)
         except Exception as e:
             UserArcaeaInfo.querying.remove(arcaea_id)
             return str(e)
         UserArcaeaInfo.querying.remove(arcaea_id)
-        name: str = data["name"]
-        character: int = data["character"]
-        is_char_uncapped: bool = data["is_char_uncapped"]
-        is_char_uncapped_override: bool = data["is_char_uncapped_override"]
-        icon = f"{character}u_icon.png" if is_char_uncapped ^ is_char_uncapped_override else f"{character}_icon.png"
-        rating: int = data["rating"]
-        song_id: str = data["recent_score"][0]["song_id"]
-        song_info: list = get_song_info()
-        song_name: str = song_info[0]["data"][song_id]["en"]
-        author_name: str = song_info[1]["data"][song_id]
-        difficulty: int = data["recent_score"][0]["difficulty"]
-        score: int = data["recent_score"][0]["score"]
-        shiny_perfect_count: int = data["recent_score"][0]["shiny_perfect_count"]
-        perfect_count: int = data["recent_score"][0]["perfect_count"]
-        near_count: int = data["recent_score"][0]["near_count"]
-        miss_count: int = data["recent_score"][0]["miss_count"]
-        health: int = data["recent_score"][0]["health"]
-        song_rating: float = data["recent_score"][0]["rating"]
-        constant: float = data["recent_score"][0]["constant"]
+        name: str = data.name
+        character: int = data.character
+        icon = data.icon
+        rating: int = data.rating
+        song_id: str = data.song_id
+        song_name: str = data.song_name
+        author_name: str = data.author_name
+        difficulty: int = data.difficulty
+        score: int = data.score
+        shiny_perfect_count: int = data.shiny_perfect_count
+        perfect_count: int = data.perfect_count
+        near_count: int = data.near_count
+        miss_count: int = data.miss_count
+        health: int = data.health
+        song_rating: float = data.song_rating
+        constant: float = data.constant
+        full_character = data.full_character
         image = Image.new("RGBA", (1280, 720))
         background = open_img(StaticPath.recent_background)
         image.alpha_composite(background)
         icon = open_img(StaticPath.select_image(
             "char", icon)).resize((130, 130))
         image.alpha_composite(icon, (575, -15))
-        full_character = f"{character}u.png" if is_char_uncapped ^ is_char_uncapped_override else f"{character}.png"
         song_cover = open_img(StaticPath.select_image(
-            "song", data["recent_score"][0]["song_id"], "base.jpg")).resize((375, 375))
+            "song", song_id, "base.jpg")).resize((375, 375))
         image.alpha_composite(song_cover, (40, 290))
         track_info = open_img(StaticPath.is_failed(
             character=character, health=health, score=score, lost_count=miss_count))
@@ -327,8 +247,10 @@ class UserArcaeaInfo:
         write_miss_count = DataText(670+(4-len(str(miss_count))/2 * 15), 610, 30, str(
             miss_count), StaticPath.geosans_light)
         image = draw_text(image, write_miss_count, 137, 137, 137, 255)
-        write_ptt = DataText(660, 70, 30, str(
-            round(rating/100, 2)), StaticPath.exo_regular)
-        image = draw_text(image, write_ptt, stroke_fill="Black", stroke_width=2)
+        raw_ptt = str(round(rating/100, 2)).split(".")
+        write_ptt_head = DataText(690, 100, 30, raw_ptt[0], StaticPath.exo_semibold, anchor="rs")
+        image = draw_text(image, write_ptt_head, stroke_fill="Black", stroke_width=2)
+        write_ptt_tail = DataText(690, 100, 20, "."+raw_ptt[1], StaticPath.exo_semibold, anchor="ls")
+        image = draw_text(image, write_ptt_tail, stroke_fill="Black", stroke_width=2)
         image.save(StaticPath.output(str(arcaea_id) + "_recent"))
         return MessageSegment.image("file:///"+StaticPath.output(str(arcaea_id) + "_recent"))
